@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/efglayout.cc,v $
-// $Date: 2003/09/06 19:55:42 $
-// $Revision: 1.34.2.2 $
+// $Date: 2004/08/17 17:53:50 $
+// $Revision: 1.34.2.9 $
 //
 // DESCRIPTION:
 // Implementation of tree layout representation
@@ -342,30 +342,46 @@ wxString efgTreeLayout::CreateNodeAboveLabel(const NodeEntry *p_entry) const
     
   switch (m_parent->DrawSettings().NodeAboveLabel()) {
   case NODE_ABOVE_NOTHING:
-    return "";
+    return _T("");
   case NODE_ABOVE_LABEL:
-    return (const char *) n->GetName();
+    return wxString::Format(_T("%s"), (const char *) n->GetName());
   case NODE_ABOVE_PLAYER:
-    return ((const char *) 
-	    ((n->GetPlayer()) ? n->GetPlayer()->GetName() : gText("")));
+    if (n->GetPlayer()) {
+      return wxString::Format(_T("%s"), (const char *) n->GetPlayer()->GetName());
+    }
+    else {
+      return _T("");
+    }
   case NODE_ABOVE_ISETLABEL:
-    return ((const char *)
-	    ((n->GetInfoset()) ? n->GetInfoset()->GetName() : gText("")));
+    if (n->GetInfoset()) {
+      return wxString::Format(_T("%s"), (const char *) n->GetInfoset()->GetName());
+    }
+    else {
+      return _T("");
+    }
   case NODE_ABOVE_ISETID:
-    return ((const char *)
-	    ((n->GetInfoset()) ?
-	     ("(" + ToText(n->GetPlayer()->GetNumber()) +
-	      "," + ToText(n->GetInfoset()->GetNumber()) + ")") : gText("")));
+    if (n->GetInfoset()) {
+      return wxString::Format(_T("%s"), (const char *)
+			      ("(" + ToText(n->GetPlayer()->GetNumber()) +
+			       "," + ToText(n->GetInfoset()->GetNumber()) + ")"));
+    }
+    else {
+      return _T("");
+    }
   case NODE_ABOVE_OUTCOME:
-    return (const char *) m_parent->OutcomeAsString(n);
+    return wxString::Format(_T("%s"), 
+			    (const char *) m_parent->OutcomeAsString(n));
   case NODE_ABOVE_REALIZPROB:
-    return (const char *) m_parent->Parent()->GetRealizProb(n);
+    return wxString::Format(_T("%s"), 
+			    (const char *) m_parent->Parent()->GetRealizProb(n));
   case NODE_ABOVE_BELIEFPROB:
-    return (const char *) m_parent->Parent()->GetBeliefProb(n);
+    return wxString::Format(_T("%s"),
+			    (const char *) m_parent->Parent()->GetBeliefProb(n));
   case NODE_ABOVE_VALUE:
-    return (const char *) m_parent->Parent()->GetNodeValue(n);
+    return wxString::Format(_T("%s"), 
+			    (const char *) m_parent->Parent()->GetNodeValue(n));
   default:
-    return "";
+    return _T("");
   }
 }    
 
@@ -375,30 +391,46 @@ wxString efgTreeLayout::CreateNodeBelowLabel(const NodeEntry *p_entry) const
 
   switch (m_parent->DrawSettings().NodeBelowLabel()) { 
   case NODE_BELOW_NOTHING:
-    return "";
+    return _T("");
   case NODE_BELOW_LABEL:
-    return (const char *) n->GetName();
+    return wxString::Format(_T("%s"), (const char *) n->GetName());
   case NODE_BELOW_PLAYER:
-    return ((const char *)
-	    ((n->GetPlayer()) ? n->GetPlayer()->GetName() : gText("")));
+    if (n->GetPlayer()) {
+      return wxString::Format(_T("%s"), (const char *) n->GetPlayer()->GetName());
+    }
+    else {
+      return _T("");
+    }
   case NODE_BELOW_ISETLABEL:
-    return ((const char *)
-	    ((n->GetInfoset()) ? n->GetInfoset()->GetName() : gText("")));
+    if (n->GetInfoset()) {
+      return wxString::Format(_T("%s"), (const char *) n->GetInfoset()->GetName());
+    }
+    else {
+      return _T("");
+    }
   case NODE_BELOW_ISETID:
-    return ((const char *)
-	    ((n->GetInfoset()) ?
-	     ("(" + ToText(n->GetPlayer()->GetNumber()) +
-	      "," + ToText(n->GetInfoset()->GetNumber()) + ")") : gText("")));
+    if (n->GetInfoset()) {
+      return wxString::Format(_T("%s"), (const char *)
+			      ("(" + ToText(n->GetPlayer()->GetNumber()) +
+			       "," + ToText(n->GetInfoset()->GetNumber()) + ")"));
+    }
+    else {
+      return _T("");
+    }
   case NODE_BELOW_OUTCOME:
-    return (const char *) m_parent->OutcomeAsString(n);
+    return wxString::Format(_T("%s"), 
+			    (const char *) m_parent->OutcomeAsString(n));
   case NODE_BELOW_REALIZPROB:
-    return (const char *) m_parent->Parent()->GetRealizProb(n);
+    return wxString::Format(_T("%s"), 
+			    (const char *) m_parent->Parent()->GetRealizProb(n));
   case NODE_BELOW_BELIEFPROB:
-    return (const char *) m_parent->Parent()->GetBeliefProb(n);
+    return wxString::Format(_T("%s"),
+			    (const char *) m_parent->Parent()->GetBeliefProb(n));
   case NODE_BELOW_VALUE:
-    return (const char *) m_parent->Parent()->GetNodeValue(n);
+    return wxString::Format(_T("%s"), 
+			    (const char *) m_parent->Parent()->GetNodeValue(n));
   default:
-    return "";
+    return _T("");
   }
 }
 
@@ -408,18 +440,19 @@ wxString efgTreeLayout::CreateNodeRightLabel(const NodeEntry *p_entry) const
 
   switch (m_parent->DrawSettings().NodeRightLabel()) { 
   case NODE_RIGHT_NOTHING:
-    return "";
+    return _T("");
   case NODE_RIGHT_OUTCOME:
-    return (const char *) m_parent->OutcomeAsString(node);
+    return wxString::Format(_T("%s"),
+			    (const char *) m_parent->OutcomeAsString(node));
   case NODE_RIGHT_NAME:
     if (node->Game()->GetOutcome(node)) {
-      return (const char *) m_efg.GetOutcomeName(node->Game()->GetOutcome(node));
+      return wxString::Format(_T("%s"), (const char *) m_efg.GetOutcomeName(node->Game()->GetOutcome(node)));
     }
     else {
-      return "";
+      return _T("");
     }
   default:
-    return "";
+    return _T("");
   }
 }
 
@@ -429,17 +462,17 @@ wxString efgTreeLayout::CreateBranchAboveLabel(const NodeEntry *p_entry) const
 
   switch (m_parent->DrawSettings().BranchAboveLabel()) {
   case BRANCH_ABOVE_NOTHING:
-    return "";
+    return _T("");
   case BRANCH_ABOVE_LABEL:
-    return (const char *) parent->GetInfoset()->GetActionName(p_entry->GetChildNumber());
+    return wxString::Format(_T("%s"), (const char *) parent->GetInfoset()->GetActionName(p_entry->GetChildNumber()));
   case BRANCH_ABOVE_PROBS:
-    return (const char *) m_parent->Parent()->GetActionProb(parent,
-							    p_entry->GetChildNumber());
+    return wxString::Format(_T("%s"), (const char *) m_parent->Parent()->GetActionProb(parent,
+							    p_entry->GetChildNumber()));
   case BRANCH_ABOVE_VALUE:
-    return (const char *) m_parent->Parent()->GetActionValue(parent,
-							     p_entry->GetChildNumber());
+    return wxString::Format(_T("%s"), (const char *) m_parent->Parent()->GetActionValue(parent,
+							     p_entry->GetChildNumber()));
   default:
-    return "";
+    return _T("");
   }
 }
 
@@ -449,17 +482,17 @@ wxString efgTreeLayout::CreateBranchBelowLabel(const NodeEntry *p_entry) const
 
   switch (m_parent->DrawSettings().BranchBelowLabel()) {
   case BRANCH_BELOW_NOTHING:
-    return "";
+    return _T("");
   case BRANCH_BELOW_LABEL:
-    return (const char *) parent->GetInfoset()->GetActionName(p_entry->GetChildNumber());
+    return wxString::Format(_T("%s"), (const char *) parent->GetInfoset()->GetActionName(p_entry->GetChildNumber()));
   case BRANCH_BELOW_PROBS:
-    return (const char *) m_parent->Parent()->GetActionProb(parent,
-							    p_entry->GetChildNumber());
+    return wxString::Format(_T("%s"), (const char *) m_parent->Parent()->GetActionProb(parent,
+							    p_entry->GetChildNumber()));
   case BRANCH_BELOW_VALUE:
-    return (const char *) m_parent->Parent()->GetActionValue(parent,
-							     p_entry->GetChildNumber());
+    return wxString::Format(_T("%s"), (const char *) m_parent->Parent()->GetActionValue(parent,
+							     p_entry->GetChildNumber()));
   default:
-    return "";
+    return _T("");
   }
 }
 
