@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/efgshow.cc,v $
-// $Date: 2003/09/23 20:15:40 $
-// $Revision: 1.84.2.11 $
+// $Date: 2004/08/17 17:53:50 $
+// $Revision: 1.84.2.24 $
 //
 // DESCRIPTION:
 // Implementation of extensive form viewing frame
@@ -84,7 +84,7 @@ const int idINFONOTEBOOK = 995;
 BEGIN_EVENT_TABLE(EfgShow, wxFrame)
   EVT_MENU(wxID_NEW, EfgShow::OnFileNew)
   EVT_MENU(wxID_OPEN, EfgShow::OnFileOpen)
-  EVT_MENU(wxID_CLOSE, EfgShow::Close)
+  EVT_MENU(wxID_CLOSE, EfgShow::OnFileClose)
   EVT_MENU(wxID_SAVE, EfgShow::OnFileSave)
   EVT_MENU(wxID_SAVEAS, EfgShow::OnFileSave)
   EVT_MENU(efgmenuFILE_EXPORT_BMP, EfgShow::OnFileExportBMP)
@@ -136,9 +136,9 @@ BEGIN_EVENT_TABLE(EfgShow, wxFrame)
   EVT_MENU(efgmenuPROFILES_DUPLICATE, EfgShow::OnProfilesDuplicate)
   EVT_MENU(efgmenuPROFILES_DELETE, EfgShow::OnProfilesDelete)
   EVT_MENU(efgmenuPROFILES_DELETE_ALL, EfgShow::OnProfilesDeleteAll)
-  EVT_MENU(efgmenuPROFILES_PROPERTIES, EfgShow::OnProfilesProperties)
+  EVT_MENU(efgmenuPROFILES_PROPERTIES, EfgShow::OnProfilesPropertiesCmd)
   EVT_MENU(efgmenuPROFILES_REPORT, EfgShow::OnProfilesReport)
-  EVT_LIST_ITEM_ACTIVATED(idEFG_SOLUTION_LIST, EfgShow::OnProfilesProperties)
+  EVT_LIST_ITEM_ACTIVATED(idEFG_SOLUTION_LIST, EfgShow::OnProfilesPropertiesClick)
   EVT_LIST_ITEM_SELECTED(idEFG_SOLUTION_LIST, EfgShow::OnProfileSelected)
   EVT_SET_FOCUS(EfgShow::OnFocus)
   EVT_CLOSE(EfgShow::OnCloseWindow)
@@ -150,7 +150,7 @@ END_EVENT_TABLE()
 //---------------------------------------------------------------------
 
 EfgShow::EfgShow(efgGame &p_efg, wxWindow *p_parent)
-  : wxFrame(p_parent, -1, "", wxPoint(0, 0), wxSize(600, 400)),
+  : wxFrame(p_parent, -1, _T(""), wxPoint(0, 0), wxSize(600, 400)),
     m_efg(p_efg), m_treeWindow(0), 
     m_cursor(0), m_copyNode(0), m_cutNode(0),
     m_currentProfile(0), m_profileTable(0),
@@ -164,7 +164,7 @@ EfgShow::EfgShow(efgGame &p_efg, wxWindow *p_parent)
   SetIcon(wxIcon("efg_icn"));
 #else
 #include "bitmaps/efg.xbm"
-  SetIcon(wxIcon(efg_bits, efg_width, efg_height));
+  SetIcon(wxIcon(wxString::Format(_T("%s"), efg_bits), efg_width, efg_height));
 #endif
 
   CreateStatusBar();
@@ -187,7 +187,7 @@ EfgShow::EfgShow(efgGame &p_efg, wxWindow *p_parent)
   m_currentSupport->SetName("Full Support");
   m_supports.Append(m_currentSupport);
 
-  m_solutionWindow = new gbtCloseFrame(this, idSOLUTIONWINDOW, "");
+  m_solutionWindow = new gbtCloseFrame(this, idSOLUTIONWINDOW, _T(""));
   m_profileTable = new EfgProfileList(this, m_solutionWindow);
   m_solutionWindow->Show(false);
 
@@ -197,7 +197,7 @@ EfgShow::EfgShow(efgGame &p_efg, wxWindow *p_parent)
   profileSizer->Fit(m_solutionWindow);
   profileSizer->SetSizeHints(m_solutionWindow);
 
-  m_infoWindow = new gbtCloseFrame(this, idINFOWINDOW, "");
+  m_infoWindow = new gbtCloseFrame(this, idINFOWINDOW, _T(""));
   m_infoWindow->Show(false);
 
   m_infoNotebook = new wxNotebook(m_infoWindow, idINFONOTEBOOK);
@@ -209,14 +209,14 @@ EfgShow::EfgShow(efgGame &p_efg, wxWindow *p_parent)
 
   m_navigateWindow = new EfgNavigateWindow(this, m_infoNotebook);
   m_navigateWindow->Set(m_cursor);
-  m_infoNotebook->AddPage(m_navigateWindow, "Navigation");
+  m_infoNotebook->AddPage(m_navigateWindow, _T("Navigation"));
 
   m_outcomeWindow = new EfgOutcomeWindow(this, m_infoNotebook);
   m_outcomeWindow->UpdateValues();
-  m_infoNotebook->AddPage(m_outcomeWindow, "Outcomes");
+  m_infoNotebook->AddPage(m_outcomeWindow, _T("Outcomes"));
 
   m_supportWindow = new EfgSupportWindow(this, m_infoNotebook);
-  m_infoNotebook->AddPage(m_supportWindow, "Supports");
+  m_infoNotebook->AddPage(m_supportWindow, _T("Supports"));
   m_infoNotebook->SetSelection(0);
 
   m_infoWindow->SetSizer(infoWindowSizer);
@@ -510,16 +510,16 @@ gText EfgShow::UniqueSupportName(void) const
 void EfgShow::SetFilename(const wxString &p_name)
 {
   m_filename = p_name;
-  if (m_filename != "") {
-    SetTitle(wxString::Format("Gambit - [%s] %s", m_filename.c_str(), 
+  if (m_filename != _T("")) {
+    SetTitle(wxString::Format(_T("Gambit - [%s] %s"), m_filename.c_str(), 
 			      (char *) m_efg.GetTitle()));
   }
   else {
-    SetTitle(wxString::Format("Gambit - %s", (char *) m_efg.GetTitle()));
+    SetTitle(wxString::Format(_T("Gambit - %s"), (char *) m_efg.GetTitle()));
   }
-  m_infoWindow->SetTitle(wxString::Format("Gambit - Info: %s",
+  m_infoWindow->SetTitle(wxString::Format(_T("Gambit - Info: %s"),
 					  (char *) m_efg.GetTitle()));
-  m_solutionWindow->SetTitle(wxString::Format("Gambit - Profiles: %s",
+  m_solutionWindow->SetTitle(wxString::Format(_T("Gambit - Profiles: %s"),
 					      (char *) m_efg.GetTitle()));
   wxGetApp().SetFilename(this, p_name.c_str());
 }
@@ -589,137 +589,139 @@ void EfgShow::SetCursor(Node *p_node)
 void EfgShow::MakeMenus(void)
 {
   wxMenu *fileMenu = new wxMenu;
-  fileMenu->Append(wxID_NEW, "&New\tCtrl-N", "Create a new game");
-  fileMenu->Append(wxID_OPEN, "&Open\tCtrl-O", "Open a saved game");
-  fileMenu->Append(wxID_CLOSE, "&Close", "Close this window");
+  fileMenu->Append(wxID_NEW, _("&New\tCtrl-N"), _("Create a new game"));
+  fileMenu->Append(wxID_OPEN, _("&Open\tCtrl-O"), _("Open a saved game"));
+  fileMenu->Append(wxID_CLOSE, _("&Close"), _("Close this window"));
   fileMenu->AppendSeparator();
-  fileMenu->Append(wxID_SAVE, "&Save\tCtrl-S", "Save this game");
-  fileMenu->Append(wxID_SAVEAS, "Save &as", "Save game to a different file");
+  fileMenu->Append(wxID_SAVE, _("&Save\tCtrl-S"), _("Save this game"));
+  fileMenu->Append(wxID_SAVEAS, _("Save &as"), 
+		   _("Save game to a different file"));
   fileMenu->AppendSeparator();
   wxMenu *fileExportMenu = new wxMenu;
-  fileExportMenu->Append(efgmenuFILE_EXPORT_BMP, "&BMP",
-			 "Save a rendering of the game as a Windows bitmap");
-  fileExportMenu->Append(efgmenuFILE_EXPORT_JPEG, "&JPEG",
-			 "Save a rendering of the game as a JPEG image");
-  fileExportMenu->Append(efgmenuFILE_EXPORT_PNG, "&PNG",
-			 "Save a rendering of the game as a PNG image");
-  fileExportMenu->Append(efgmenuFILE_EXPORT_POSTSCRIPT, "Post&Script",
-			 "Save a printout of the game in PostScript format");
+  fileExportMenu->Append(efgmenuFILE_EXPORT_BMP, _("&BMP"),
+			 _("Save a rendering of the game as a Windows bitmap"));
+  fileExportMenu->Append(efgmenuFILE_EXPORT_JPEG, _("&JPEG"),
+			 _("Save a rendering of the game as a JPEG image"));
+  fileExportMenu->Append(efgmenuFILE_EXPORT_PNG, _("&PNG"),
+			 _("Save a rendering of the game as a PNG image"));
+  fileExportMenu->Append(efgmenuFILE_EXPORT_POSTSCRIPT, _("Post&Script"),
+			 _("Save a printout of the game in PostScript format"));
   fileExportMenu->Enable(efgmenuFILE_EXPORT_POSTSCRIPT, wxUSE_POSTSCRIPT);
-  fileMenu->Append(efgmenuFILE_EXPORT, "&Export", fileExportMenu,
-		   "Export the game in various formats");
+  fileMenu->Append(efgmenuFILE_EXPORT, _("&Export"), fileExportMenu,
+		   _("Export the game in various formats"));
   fileMenu->AppendSeparator();
-  fileMenu->Append(wxID_PRINT_SETUP, "Page Se&tup",
-		   "Set up preferences for printing");
-  fileMenu->Append(wxID_PREVIEW, "Print Pre&view",
-		   "View a preview of the game printout");
-  fileMenu->Append(wxID_PRINT, "&Print\tCtrl-P", "Print this game");
+  fileMenu->Append(wxID_PRINT_SETUP, _("Page Se&tup"),
+		   _("Set up preferences for printing"));
+  fileMenu->Append(wxID_PREVIEW, _("Print Pre&view"),
+		   _("View a preview of the game printout"));
+  fileMenu->Append(wxID_PRINT, _("&Print\tCtrl-P"), _("Print this game"));
   fileMenu->AppendSeparator();
-  fileMenu->Append(wxID_EXIT, "E&xit\tCtrl-X", "Exit Gambit");
+  fileMenu->Append(wxID_EXIT, _("E&xit\tCtrl-X"), _("Exit Gambit"));
 
   wxMenu *editMenu = new wxMenu;
-  editMenu->Append(wxID_CUT, "Cu&t", "Cut the current selection");
-  editMenu->Append(wxID_COPY, "&Copy", "Copy the current selection");
-  editMenu->Append(wxID_PASTE, "&Paste", "Paste from clipboard");
+  editMenu->Append(wxID_CUT, _("Cu&t"), _("Cut the current selection"));
+  editMenu->Append(wxID_COPY, _("&Copy"), _("Copy the current selection"));
+  editMenu->Append(wxID_PASTE, _("&Paste"), _("Paste from clipboard"));
   editMenu->AppendSeparator();
-  editMenu->Append(efgmenuEDIT_INSERT, "&Insert", "Insert a move");
-  editMenu->Append(efgmenuEDIT_DELETE, "&Delete...", "Delete an object");
-  editMenu->Append(efgmenuEDIT_REVEAL, "&Reveal", 
-		   "Reveal choice at node");
+  editMenu->Append(efgmenuEDIT_INSERT, _("&Insert"), _("Insert a move"));
+  editMenu->Append(efgmenuEDIT_DELETE, _("&Delete..."), _("Delete an object"));
+  editMenu->Append(efgmenuEDIT_REVEAL, _("&Reveal"), 
+		   _("Reveal choice at node"));
   editMenu->AppendSeparator();
-  editMenu->Append(efgmenuEDIT_TOGGLE_SUBGAME, "Mark &subgame",
-		   "Mark or unmark the subgame at this node");
-  editMenu->Append(efgmenuEDIT_MARK_SUBGAME_TREE, "Mar&k subgame tree",
-		   "Mark all subgames in this subtree");
-  editMenu->Append(efgmenuEDIT_UNMARK_SUBGAME_TREE, "&Unmark subgame tree",
-		   "Unmark all subgames in this subtree");
+  editMenu->Append(efgmenuEDIT_TOGGLE_SUBGAME, _("Mark &subgame"),
+		   _("Mark or unmark the subgame at this node"));
+  editMenu->Append(efgmenuEDIT_MARK_SUBGAME_TREE, _("Mar&k subgame tree"),
+		   _("Mark all subgames in this subtree"));
+  editMenu->Append(efgmenuEDIT_UNMARK_SUBGAME_TREE, _("&Unmark subgame tree"),
+		   _("Unmark all subgames in this subtree"));
   editMenu->AppendSeparator();
-  editMenu->Append(efgmenuEDIT_NODE, "&Node",
-		   "Edit properties of the node");
-  editMenu->Append(efgmenuEDIT_MOVE, "&Move",
-		   "Edit properties of the move");
-  editMenu->Append(efgmenuEDIT_GAME, "&Game",
-		   "Edit properties of the game");
+  editMenu->Append(efgmenuEDIT_NODE, _("&Node"),
+		   _("Edit properties of the node"));
+  editMenu->Append(efgmenuEDIT_MOVE, _("&Move"),
+		   _("Edit properties of the move"));
+  editMenu->Append(efgmenuEDIT_GAME, _("&Game"),
+		   _("Edit properties of the game"));
 
   wxMenu *toolsMenu = new wxMenu;
 
-  toolsMenu->Append(efgmenuTOOLS_DOMINANCE, "&Dominance",
-		    "Find undominated actions");
-  toolsMenu->Append(efgmenuTOOLS_EQUILIBRIUM, "&Equilibrium",
-		    "Compute Nash equilibria and refinements");
-  toolsMenu->Append(efgmenuTOOLS_QRE, "&Qre",
-		    "Compute quantal response equilibria");
+  toolsMenu->Append(efgmenuTOOLS_DOMINANCE, _("&Dominance"),
+		    _("Find undominated actions"));
+  toolsMenu->Append(efgmenuTOOLS_EQUILIBRIUM, _("&Equilibrium"),
+		    _("Compute Nash equilibria and refinements"));
+  toolsMenu->Append(efgmenuTOOLS_QRE, _("&Qre"),
+		    _("Compute quantal response equilibria"));
 
   wxMenu *toolsNfgMenu = new wxMenu;
-  toolsNfgMenu->Append(efgmenuTOOLS_NFG_REDUCED, "Reduced",
-		       "Generate reduced normal form");
-  toolsNfgMenu->Append(efgmenuTOOLS_NFG_AGENT, "Agent",
-		       "Generate agent normal form");
-  toolsMenu->Append(efgmenuTOOLS_NFG, "Normal form", toolsNfgMenu,
-		    "Create a normal form representation of this game");
+  toolsNfgMenu->Append(efgmenuTOOLS_NFG_REDUCED, _("Reduced"),
+		       _("Generate reduced normal form"));
+  toolsNfgMenu->Append(efgmenuTOOLS_NFG_AGENT, _("Agent"),
+		       _("Generate agent normal form"));
+  toolsMenu->Append(efgmenuTOOLS_NFG, _("Normal form"), toolsNfgMenu,
+		    _("Create a normal form representation of this game"));
 
   
   wxMenu *viewMenu = new wxMenu;
-  viewMenu->Append(efgmenuVIEW_PROFILES, "&Profiles",
-		   "Display/hide profiles window", true);
+  viewMenu->Append(efgmenuVIEW_PROFILES, _("&Profiles"),
+		   _("Display/hide profiles window"), true);
   viewMenu->Check(efgmenuVIEW_PROFILES, false);
   viewMenu->AppendSeparator();
-  viewMenu->Append(efgmenuVIEW_NAVIGATION, "&Navigation",
-		   "Display navigation window", true);
+  viewMenu->Append(efgmenuVIEW_NAVIGATION, _("&Navigation"),
+		   _("Display navigation window"), true);
   viewMenu->Check(efgmenuVIEW_NAVIGATION, false);
-  viewMenu->Append(efgmenuVIEW_OUTCOMES, "&Outcomes",
-		   "Display and edit outcomes", true);
+  viewMenu->Append(efgmenuVIEW_OUTCOMES, _("&Outcomes"),
+		   _("Display and edit outcomes"), true);
   viewMenu->Check(efgmenuVIEW_OUTCOMES, false);
-  viewMenu->Append(efgmenuVIEW_SUPPORTS, "&Supports",
-		   "Display and edit supports", true);
+  viewMenu->Append(efgmenuVIEW_SUPPORTS, _("&Supports"),
+		   _("Display and edit supports"), true);
   viewMenu->Check(efgmenuVIEW_SUPPORTS, false);
   viewMenu->AppendSeparator();
-  viewMenu->Append(efgmenuVIEW_ZOOMIN, "Zoom &in",
-		   "Increase display magnification");
-  viewMenu->Append(efgmenuVIEW_ZOOMOUT, "Zoom &out",
-		   "Decrease display magnification");
+  viewMenu->Append(efgmenuVIEW_ZOOMIN, _("Zoom &in"),
+		   _("Increase display magnification"));
+  viewMenu->Append(efgmenuVIEW_ZOOMOUT, _("Zoom &out"),
+		   _("Decrease display magnification"));
   viewMenu->AppendSeparator();
-  viewMenu->Append(efgmenuVIEW_SUPPORT_REACHABLE, "&Root Reachable",
-		   "Display only nodes that are support-reachable",
+  viewMenu->Append(efgmenuVIEW_SUPPORT_REACHABLE, _("&Root Reachable"),
+		   _("Display only nodes that are support-reachable"),
 		   true);
   
   wxMenu *formatMenu = new wxMenu;
   wxMenu *formatDisplayMenu = new wxMenu;
-  formatDisplayMenu->Append(efgmenuFORMAT_DISPLAY_LAYOUT, "&Layout",
-			    "Set tree layout parameters");
-  formatDisplayMenu->Append(efgmenuFORMAT_DISPLAY_LEGEND, "Le&gends",
-			    "Set legends");
-  formatDisplayMenu->Append(efgmenuFORMAT_DISPLAY_COLORS, "&Colors",
-			    "Set colors");
-  formatDisplayMenu->Append(efgmenuFORMAT_DISPLAY_DECIMALS, "&Decimal Places",
-			   "Set number of decimal places to display");
-  formatMenu->Append(efgmenuFORMAT_DISPLAY, "&Display", formatDisplayMenu,
-		     "Set display options");
+  formatDisplayMenu->Append(efgmenuFORMAT_DISPLAY_LAYOUT, _("&Layout"),
+			    _("Set tree layout parameters"));
+  formatDisplayMenu->Append(efgmenuFORMAT_DISPLAY_LEGEND, _("Le&gends"),
+			    _("Set legends"));
+  formatDisplayMenu->Append(efgmenuFORMAT_DISPLAY_COLORS, _("&Colors"),
+			    _("Set colors"));
+  formatDisplayMenu->Append(efgmenuFORMAT_DISPLAY_DECIMALS, 
+			    _("&Decimal Places"),
+			    _("Set number of decimal places to display"));
+  formatMenu->Append(efgmenuFORMAT_DISPLAY, _("&Display"), formatDisplayMenu,
+		     _("Set display options"));
   
   wxMenu *formatFontsMenu = new wxMenu;
-  formatFontsMenu->Append(efgmenuFORMAT_FONTS_ABOVENODE, "Above Node",
-			 "Font for label above nodes");
-  formatFontsMenu->Append(efgmenuFORMAT_FONTS_BELOWNODE, "Below Node",
-			 "Font for label below nodes");
-  formatFontsMenu->Append(efgmenuFORMAT_FONTS_AFTERNODE, "After Node",
-			 "Font for label to right of nodes");
-  formatFontsMenu->Append(efgmenuFORMAT_FONTS_ABOVEBRANCH, "Above Branch",
-			 "Font for label above branches");
-  formatFontsMenu->Append(efgmenuFORMAT_FONTS_BELOWBRANCH, "Below Branch",
-			 "Font for label below branches");
-  formatMenu->Append(efgmenuFORMAT_FONTS, "&Fonts", formatFontsMenu,
-		     "Set display fonts");
+  formatFontsMenu->Append(efgmenuFORMAT_FONTS_ABOVENODE, _("Above Node"),
+			  _("Font for label above nodes"));
+  formatFontsMenu->Append(efgmenuFORMAT_FONTS_BELOWNODE, _("Below Node"),
+			  _("Font for label below nodes"));
+  formatFontsMenu->Append(efgmenuFORMAT_FONTS_AFTERNODE, _("After Node"),
+			  _("Font for label to right of nodes"));
+  formatFontsMenu->Append(efgmenuFORMAT_FONTS_ABOVEBRANCH, _("Above Branch"),
+			  _("Font for label above branches"));
+  formatFontsMenu->Append(efgmenuFORMAT_FONTS_BELOWBRANCH, _("Below Branch"),
+			  _("Font for label below branches"));
+  formatMenu->Append(efgmenuFORMAT_FONTS, _("&Fonts"), formatFontsMenu,
+		     _("Set display fonts"));
   
   wxMenu *helpMenu = new wxMenu;
-  helpMenu->Append(wxID_ABOUT, "&About", "About Gambit");
+  helpMenu->Append(wxID_ABOUT, _("&About"), _("About Gambit"));
 
   wxMenuBar *menuBar = new wxMenuBar(wxMB_DOCKABLE);
-  menuBar->Append(fileMenu, "&File");
-  menuBar->Append(editMenu, "&Edit");
-  menuBar->Append(viewMenu, "&View");
-  menuBar->Append(formatMenu, "&Format");
-  menuBar->Append(toolsMenu, "&Tools");
-  menuBar->Append(helpMenu, "&Help");
+  menuBar->Append(fileMenu, _("&File"));
+  menuBar->Append(editMenu, _("&Edit"));
+  menuBar->Append(viewMenu, _("&View"));
+  menuBar->Append(formatMenu, _("&Format"));
+  menuBar->Append(toolsMenu, _("&Tools"));
+  menuBar->Append(helpMenu, _("&Help"));
 
   // Set the menu bar
   SetMenuBar(menuBar);
@@ -748,10 +750,11 @@ void EfgShow::UpdateMenus(void)
   menuBar->Enable(efgmenuEDIT_UNMARK_SUBGAME_TREE,
 		  (cursor && m_efg.IsLegalSubgame(cursor)));
   menuBar->SetLabel(efgmenuEDIT_TOGGLE_SUBGAME,
-		    (cursor && cursor->GetParent() &&
-		     m_efg.IsLegalSubgame(cursor) &&
-		     cursor->GetSubgameRoot() == cursor) ?
-		    "Unmark &subgame" : "Mark &subgame");
+		    wxString::Format(_T("%s"),
+				     (cursor && cursor->GetParent() &&
+				      m_efg.IsLegalSubgame(cursor) &&
+				      cursor->GetSubgameRoot() == cursor) ?
+				     "Unmark &subgame" : "Mark &subgame"));
 
   menuBar->Enable(efgmenuEDIT_NODE, (cursor) ? true : false);
   menuBar->Enable(efgmenuEDIT_MOVE,
@@ -781,28 +784,28 @@ void EfgShow::MakeToolbar(void)
   toolBar->SetMargins(4, 4);
 
   toolBar->AddTool(wxID_NEW, wxBITMAP(new), wxNullBitmap, false,
-		   -1, -1, 0, "New game", "Create a new game");
+		   -1, -1, 0, _("New game"), _("Create a new game"));
   toolBar->AddTool(wxID_OPEN, wxBITMAP(open), wxNullBitmap, false,
-		   -1, -1, 0, "Open file", "Open a saved game");
+		   -1, -1, 0, _("Open file"), _("Open a saved game"));
   toolBar->AddTool(wxID_SAVE, wxBITMAP(save), wxNullBitmap, false,
-		   -1, -1, 0, "Save game", "Save this game");
+		   -1, -1, 0, _("Save game"), _("Save this game"));
   toolBar->AddSeparator();
 
   toolBar->AddTool(wxID_PREVIEW, wxBITMAP(preview), wxNullBitmap,
-		   false, -1, -1, 0, "Print Preview",
-		   "View a preview of the game printout");
+		   false, -1, -1, 0, _("Print Preview"),
+		   _("View a preview of the game printout"));
   toolBar->AddTool(wxID_PRINT, wxBITMAP(print), wxNullBitmap, false,
-		   -1, -1, 0, "Print", "Print this game");
+		   -1, -1, 0, _("Print"), _("Print this game"));
   toolBar->AddSeparator();
 
   toolBar->AddTool(efgmenuVIEW_ZOOMIN, wxBITMAP(zoomin), wxNullBitmap,
-		   false, -1, -1, 0, "Zoom in", "Increase magnification");
+		   false, -1, -1, 0, _("Zoom in"), _("Increase magnification"));
   toolBar->AddTool(efgmenuVIEW_ZOOMOUT, wxBITMAP(zoomout), wxNullBitmap,
-		   false, -1, -1, 0, "Zoom out", "Decrease magnification");
+		   false, -1, -1, 0, _("Zoom out"), _("Decrease magnification"));
   toolBar->AddSeparator();
 
   toolBar->AddTool(wxID_ABOUT, wxBITMAP(help), wxNullBitmap, false,
-		   -1, -1, 0, "Help", "Table of contents");
+		   -1, -1, 0, _("Help"), _("Table of contents"));
 
   toolBar->Realize();
   toolBar->SetRows(1);
@@ -822,11 +825,16 @@ void EfgShow::OnFileOpen(wxCommandEvent &)
   wxGetApp().OnFileOpen(this);
 }
 
+void EfgShow::OnFileClose(wxCommandEvent &)
+{
+  Close();
+}
+
 void EfgShow::OnFileSave(wxCommandEvent &p_event)
 {
-  if (p_event.GetId() == wxID_SAVEAS || m_filename == "") {
-    wxFileDialog dialog(this, "Choose file", wxPathOnly(m_filename),
-			wxFileNameFromPath(m_filename), "*.efg",
+  if (p_event.GetId() == wxID_SAVEAS || m_filename == _T("")) {
+    wxFileDialog dialog(this, _("Choose file"), wxPathOnly(m_filename),
+			wxFileNameFromPath(m_filename), _T("*.efg"),
 			wxSAVE | wxOVERWRITE_PROMPT);
 
     switch (dialog.ShowModal()) {
@@ -841,26 +849,26 @@ void EfgShow::OnFileSave(wxCommandEvent &p_event)
 
   efgGame *efg = 0;
   try {
-    gFileOutput file(m_filename);
+    gFileOutput file((const char *) m_filename.mb_str());
     efg = CompressEfg(m_efg, *GetSupport());
     efg->WriteEfgFile(file, 6);
     m_efg.SetIsDirty(false);
     delete efg;
   }
   catch (gFileOutput::OpenFailed &) {
-    wxMessageBox(wxString::Format("Could not open %s for writing.",
-				  m_filename.c_str()),
-		 "Error", wxOK, this);
+    wxMessageBox(wxString::Format(_("Could not open %s for writing."),
+				  (const char *) m_filename.mb_str()),
+		 _("Error"), wxOK, this);
     if (efg)  delete efg;
   }
   catch (gFileOutput::WriteFailed &) {
-    wxMessageBox(wxString::Format("Write error occurred in saving %s.\n",
-				  m_filename.c_str()),
-		 "Error", wxOK, this);
+    wxMessageBox(wxString::Format(_("Write error occurred in saving %s."),
+				  (const char *) m_filename.mb_str()),
+		 _("Error"), wxOK, this);
     if (efg)  delete efg;
   }
   catch (efgGame::Exception &) {
-    wxMessageBox("Internal exception in extensive form", "Error",
+    wxMessageBox(_("Internal exception in extensive form"), _("Error"),
 		 wxOK, this);
     if (efg)  delete efg;
   }
@@ -879,8 +887,10 @@ void EfgShow::OnFilePrintPreview(wxCommandEvent &)
 {
   wxPrintDialogData data(m_printData);
   wxPrintPreview *preview = 
-    new wxPrintPreview(new EfgPrintout(m_treeWindow,(char *) m_efg.GetTitle()),
-		       new EfgPrintout(m_treeWindow,(char *) m_efg.GetTitle()),
+    new wxPrintPreview(new EfgPrintout(m_treeWindow,
+				       wxString::Format(_T("%s"), (char *) m_efg.GetTitle())),
+		       new EfgPrintout(m_treeWindow,
+				       wxString::Format(_T("%s"), (char *) m_efg.GetTitle())),
 		       &data);
 
   if (!preview->Ok()) {
@@ -889,7 +899,7 @@ void EfgShow::OnFilePrintPreview(wxCommandEvent &)
   }
 
   wxPreviewFrame *frame = new wxPreviewFrame(preview, this,
-					     "Print Preview",
+					     _("Print Preview"),
 					     wxPoint(100, 100),
 					     wxSize(600, 650));
   frame->Initialize();
@@ -900,11 +910,12 @@ void EfgShow::OnFilePrint(wxCommandEvent &)
 {
   wxPrintDialogData data(m_printData);
   wxPrinter printer(&data);
-  EfgPrintout printout(m_treeWindow, (char *) m_efg.GetTitle());
+  EfgPrintout printout(m_treeWindow,
+		       wxString::Format(_T("%s"), (char *) m_efg.GetTitle()));
 
   if (!printer.Print(this, &printout, true)) {
     if (wxPrinter::GetLastError() == wxPRINTER_ERROR) {
-      wxMessageBox("There was an error in printing", "Error", wxOK);
+      wxMessageBox(_("There was an error in printing"), _("Error"), wxOK);
     }
     // Otherwise, user hit "cancel"; just be quiet and return.
     return;
@@ -916,8 +927,9 @@ void EfgShow::OnFilePrint(wxCommandEvent &)
 
 void EfgShow::OnFileExportBMP(wxCommandEvent &)
 {
-  wxFileDialog dialog(this, "Choose output file", wxGetApp().CurrentDir(), "",
-		      "Windows bitmap files (*.bmp)|*.bmp", wxSAVE);
+  wxFileDialog dialog(this, _("Choose output file"), 
+		      wxGetApp().CurrentDir(), _T(""),
+		      _T("Windows bitmap files (*.bmp)|*.bmp"), wxSAVE);
 
   if (dialog.ShowModal() == wxID_OK) {
     wxMemoryDC dc;
@@ -926,18 +938,19 @@ void EfgShow::OnFileExportBMP(wxCommandEvent &)
     dc.SelectObject(bitmap);
     m_treeWindow->OnDraw(dc, 1.0);
     if (!bitmap.SaveFile(dialog.GetPath(), wxBITMAP_TYPE_BMP)) {
-      wxMessageBox(wxString::Format("An error occurred in writing '%s'.\n",
-				    dialog.GetPath().c_str()),
-		   "Error", wxOK, this);
+      wxMessageBox(wxString::Format(_("An error occurred in writing '%s'."),
+				    (const char *) dialog.GetPath().mb_str()),
+		   _("Error"), wxOK, this);
     }
   }
 }
 
 void EfgShow::OnFileExportJPEG(wxCommandEvent &)
 {
-  wxFileDialog dialog(this, "Choose output file", wxGetApp().CurrentDir(), "",
-		      "JPEG files (*.jpeg)|*.jpeg|"
-		      "JPEG files (*.jpg)|*.jpg", wxSAVE);
+  wxFileDialog dialog(this, _("Choose output file"), 
+		      wxGetApp().CurrentDir(), _T(""),
+		      _T("JPEG files (*.jpeg)|*.jpeg|"
+			 "JPEG files (*.jpg)|*.jpg"), wxSAVE);
 
   if (dialog.ShowModal() == wxID_OK) {
     wxMemoryDC dc;
@@ -946,17 +959,18 @@ void EfgShow::OnFileExportJPEG(wxCommandEvent &)
     dc.SelectObject(bitmap);
     m_treeWindow->OnDraw(dc, 1.0);
     if (!bitmap.SaveFile(dialog.GetPath(), wxBITMAP_TYPE_JPEG)) {
-      wxMessageBox(wxString::Format("An error occurred in writing '%s'.\n",
-				    dialog.GetPath().c_str()),
-		   "Error", wxOK, this);
+      wxMessageBox(wxString::Format(_("An error occurred in writing '%s'."),
+				    (const char *) dialog.GetPath().mb_str()),
+		   _("Error"), wxOK, this);
     }
   }
 }
 
 void EfgShow::OnFileExportPNG(wxCommandEvent &)
 {
-  wxFileDialog dialog(this, "Choose output file", wxGetApp().CurrentDir(), "",
-		      "PNG files (*.png)|*.png", wxSAVE);
+  wxFileDialog dialog(this, _("Choose output file"),
+		      wxGetApp().CurrentDir(), _(""),
+		      _T("PNG files (*.png)|*.png"), wxSAVE);
 
   if (dialog.ShowModal() == wxID_OK) {
     wxMemoryDC dc;
@@ -965,9 +979,9 @@ void EfgShow::OnFileExportPNG(wxCommandEvent &)
     dc.SelectObject(bitmap);
     m_treeWindow->OnDraw(dc, 1.0);
     if (!bitmap.SaveFile(dialog.GetPath(), wxBITMAP_TYPE_PNG)) {
-      wxMessageBox(wxString::Format("An error occurred in writing '%s'.\n",
-				    dialog.GetPath().c_str()),
-		   "Error", wxOK, this);
+      wxMessageBox(wxString::Format(_("An error occurred in writing '%s'"),
+				    (const char *) dialog.GetPath().mb_str()),
+		   _("Error"), wxOK, this);
     }
   }
 }
@@ -977,8 +991,9 @@ void EfgShow::OnFileExportPS(wxCommandEvent &)
 #if wxUSE_POSTSCRIPT
   wxPrintData printData(m_printData);
 
-  wxFileDialog dialog(this, "Choose output file", wxGetApp().CurrentDir(), "",
-		      "PostScript files (*.ps)|*.ps", wxSAVE);
+  wxFileDialog dialog(this, _("Choose output file"),
+		      wxGetApp().CurrentDir(), _T(""),
+		      _T("PostScript files (*.ps)|*.ps"), wxSAVE);
 
   if (dialog.ShowModal() == wxID_OK) {
     printData.SetFilename(dialog.GetPath());
@@ -991,7 +1006,7 @@ void EfgShow::OnFileExportPS(wxCommandEvent &)
   // This code is borrowed from the extensive form printout class.
   // Seems like it would be nice to consolidate it in one place.
   wxPostScriptDC dc(printData);
-  dc.StartDoc("Extensive form game");
+  dc.StartDoc(_T("Extensive form game"));
   dc.SetBackgroundMode(wxTRANSPARENT);
   dc.StartPage();
 
@@ -1117,6 +1132,7 @@ void EfgShow::OnEditDelete(wxCommandEvent &)
       else {
 	Node *keep = dialog.KeepNode();
 	m_treeWindow->SetCursorPosition(m_efg.DeleteNode(Cursor(), keep));
+	SetCursor(keep);
       }
       m_efg.DeleteEmptyInfosets();
       OnTreeChanged(true, true);
@@ -1180,7 +1196,7 @@ void EfgShow::OnEditNode(wxCommandEvent &)
 {
   dialogEditNode dialog(this, Cursor());
   if (dialog.ShowModal() == wxID_OK) {
-    Cursor()->SetName(dialog.GetNodeName().c_str());
+    Cursor()->SetName((const char *) dialog.GetNodeName().mb_str());
     if (dialog.GetOutcome() > 0) {
       m_efg.SetOutcome(Cursor(), m_efg.GetOutcome(dialog.GetOutcome()));
     }
@@ -1204,6 +1220,7 @@ void EfgShow::OnEditNode(wxCommandEvent &)
       }
       else {
 	m_efg.JoinInfoset(dialog.GetInfoset(), Cursor());
+	m_efg.DeleteEmptyInfosets();
       }
       OnTreeChanged(true, true);
     }
@@ -1219,7 +1236,7 @@ void EfgShow::OnEditMove(wxCommandEvent &)
 
   dialogEditMove dialog(this, infoset);
   if (dialog.ShowModal() == wxID_OK) {
-    infoset->SetName(dialog.GetInfosetName().c_str());
+    infoset->SetName((const char *) dialog.GetInfosetName().mb_str());
     
     if (!infoset->IsChanceInfoset() && 
 	dialog.GetPlayer() != infoset->GetPlayer()->GetNumber()) {
@@ -1273,15 +1290,15 @@ void EfgShow::OnEditGame(wxCommandEvent &)
 {
   dialogEditEfg dialog(this, m_efg, m_filename);
   if (dialog.ShowModal() == wxID_OK) {
-    m_efg.SetTitle(dialog.GetGameTitle().c_str());
+    m_efg.SetTitle((const char *) dialog.GetGameTitle().mb_str());
     SetFilename(Filename());
-    m_efg.SetComment(dialog.GetComment().c_str());
+    m_efg.SetComment((const char *) dialog.GetComment().mb_str());
     for (int pl = 1; pl <= dialog.NumPlayers(); pl++) {
       if (pl > m_efg.NumPlayers()) {
-	m_efg.NewPlayer()->SetName(dialog.GetPlayerName(pl).c_str());
+	m_efg.NewPlayer()->SetName((const char *) dialog.GetPlayerName(pl).mb_str());
       }
       else {
-	m_efg.Players()[pl]->SetName(dialog.GetPlayerName(pl).c_str());
+	m_efg.Players()[pl]->SetName((const char *) dialog.GetPlayerName(pl).mb_str());
       }
     }
     m_outcomeWindow->UpdateValues();
@@ -1503,7 +1520,7 @@ void EfgShow::OnFormatDisplayColors(wxCommandEvent &)
 
 void EfgShow::OnFormatDisplayDecimals(wxCommandEvent &)
 {
-  dialogSpinCtrl dialog(this, "Decimal places", 0, 25,
+  dialogSpinCtrl dialog(this, _("Decimal places"), 0, 25,
 			m_treeWindow->DrawSettings().NumDecimals());
 
   if (dialog.ShowModal() == wxID_OK) {
@@ -1597,14 +1614,15 @@ void EfgShow::OnToolsEquilibrium(wxCommandEvent &)
       UpdateMenus();
     }
     catch (gException &ex) {
-      wxMessageDialog msgDialog(this, (char *) ex.Description(),
-				"Gambit exception", wxOK);
+      wxMessageDialog msgDialog(this, 
+				wxString::Format(_T("%s"), (char *) ex.Description()),
+				_("Gambit exception"), wxOK);
       msgDialog.ShowModal();
     }
     catch (...) {
       wxMessageDialog msgDialog(this,
-				"An internal exception occurred while solving",
-				"Gambit exception", wxOK);
+				_("An internal exception occurred while solving"),
+				_("Gambit exception"), wxOK);
       msgDialog.ShowModal();
     }
 
@@ -1639,9 +1657,9 @@ void EfgShow::OnToolsNormalReduced(wxCommandEvent &)
 {
   // check that the game is perfect recall, if not give a warning
   if (!IsPerfectRecall(m_efg)) {
-    if (wxMessageBox("This game is not perfect recall\n"
-		     "Do you wish to continue?", 
-		     "Reduced normal form", 
+    if (wxMessageBox(_("This game is not perfect recall\n"
+		       "Do you wish to continue?"), 
+		     _("Reduced normal form"), 
 		     wxOK | wxCANCEL | wxCENTRE, this) != wxOK) {
       return;
     }
@@ -1654,7 +1672,7 @@ void EfgShow::OnToolsNormalReduced(wxCommandEvent &)
   Nfg *nfg = MakeReducedNfg(*m_currentSupport);
   if (nfg) {
     NfgShow *nfgShow = new NfgShow(*nfg, m_parent);
-    nfgShow->SetFilename("");
+    nfgShow->SetFilename(_T(""));
     wxGetApp().AddGame(&m_efg, nfg, nfgShow);
 
     for (int i = 1; i <= m_profiles.Length(); i++) {
@@ -1668,8 +1686,8 @@ void EfgShow::OnToolsNormalReduced(wxCommandEvent &)
     }
   }
   else {
-    wxMessageBox("Could not create normal form game.\n",
-		 "Reduced normal form", wxOK);
+    wxMessageBox(_("Could not create normal form game."),
+		 _("Reduced normal form"), wxOK);
   }
 }
 
@@ -1677,9 +1695,9 @@ void EfgShow::OnToolsNormalAgent(wxCommandEvent &)
 {
   // check that the game is perfect recall, if not give a warning
   if (!IsPerfectRecall(m_efg)) {
-    if (wxMessageBox("This game is not perfect recall\n"
-		     "Do you wish to continue?", 
-		     "Agent normal form", 
+    if (wxMessageBox(_("This game is not perfect recall\n"
+		       "Do you wish to continue?"), 
+		     _("Agent normal form"), 
 		     wxOK | wxCANCEL | wxCENTRE, this) != wxOK) {
       return;
     }
@@ -1769,7 +1787,19 @@ void EfgShow::OnProfilesDeleteAll(wxCommandEvent &)
   ChangeProfile(0);
 }
 
-void EfgShow::OnProfilesProperties(wxCommandEvent &)
+void EfgShow::OnProfilesPropertiesCmd(wxCommandEvent &)
+{
+  if (m_currentProfile > 0) {
+    dialogEditBehav dialog(this, m_profiles[m_currentProfile]);
+
+    if (dialog.ShowModal() == wxID_OK) {
+      m_profiles[m_currentProfile] = dialog.GetProfile();
+      ChangeProfile(m_currentProfile);
+    }
+  }
+}
+
+void EfgShow::OnProfilesPropertiesClick(wxListEvent &)
 {
   if (m_currentProfile > 0) {
     dialogEditBehav dialog(this, m_profiles[m_currentProfile]);
@@ -1828,7 +1858,8 @@ void EfgShow::OnInfoNotebookPage(wxNotebookEvent &p_event)
 void EfgShow::OnCloseWindow(wxCloseEvent &p_event)
 {
   if (p_event.CanVeto() && m_efg.IsDirty()) {
-    if (wxMessageBox("Game has been modified.  Close anyway?", "Warning",
+    if (wxMessageBox(_("Game has been modified.  Close anyway?"), 
+		     _("Warning"),
 		     wxOK | wxCANCEL) == wxCANCEL) {
       p_event.Veto();
       return;
