@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/nfgshow.cc,v $
-// $Date: 2003/09/23 20:15:41 $
-// $Revision: 1.52.2.9 $
+// $Date: 2004/08/17 17:53:51 $
+// $Revision: 1.52.2.26 $
 //
 // DESCRIPTION:
 // Implementation of normal form display class
@@ -75,9 +75,11 @@ const int idINFOWINDOW = 3004;
 BEGIN_EVENT_TABLE(NfgShow, wxFrame)
   EVT_MENU(wxID_NEW, NfgShow::OnFileNew)
   EVT_MENU(wxID_OPEN, NfgShow::OnFileOpen)
-  EVT_MENU(wxID_CLOSE, NfgShow::Close)
+  EVT_MENU(wxID_CLOSE, NfgShow::OnFileClose)
   EVT_MENU(wxID_SAVE, NfgShow::OnFileSave)
   EVT_MENU(wxID_SAVEAS, NfgShow::OnFileSave)
+  EVT_MENU(NFG_FILE_EXPORT_HTML, NfgShow::OnFileExportHTML)
+  EVT_MENU(NFG_FILE_EXPORT_OSBORNE, NfgShow::OnFileExportOsborne)
   EVT_MENU(wxID_PRINT_SETUP, NfgShow::OnFilePageSetup)
   EVT_MENU(wxID_PREVIEW, NfgShow::OnFilePrintPreview)
   EVT_MENU(wxID_PRINT, NfgShow::OnFilePrint)
@@ -107,9 +109,9 @@ BEGIN_EVENT_TABLE(NfgShow, wxFrame)
   EVT_MENU(NFG_PROFILES_DUPLICATE, NfgShow::OnProfilesDuplicate)
   EVT_MENU(NFG_PROFILES_DELETE, NfgShow::OnProfilesDelete)
   EVT_MENU(NFG_PROFILES_DELETE_ALL, NfgShow::OnProfilesDeleteAll)
-  EVT_MENU(NFG_PROFILES_PROPERTIES, NfgShow::OnProfilesProperties)
+  EVT_MENU(NFG_PROFILES_PROPERTIES, NfgShow::OnProfilesPropertiesCmd)
   EVT_MENU(NFG_PROFILES_REPORT, NfgShow::OnProfilesReport)
-  EVT_LIST_ITEM_ACTIVATED(idNFG_SOLUTION_LIST, NfgShow::OnProfilesProperties)
+  EVT_LIST_ITEM_ACTIVATED(idNFG_SOLUTION_LIST, NfgShow::OnProfilesPropertiesClick)
   EVT_LIST_ITEM_SELECTED(idNFG_SOLUTION_LIST, NfgShow::OnProfileSelected)
   EVT_CLOSE(NfgShow::OnCloseWindow)
   EVT_SET_FOCUS(NfgShow::OnSetFocus)
@@ -121,7 +123,7 @@ END_EVENT_TABLE()
 //----------------------------------------------------------------------
 
 NfgShow::NfgShow(Nfg &p_nfg, wxWindow *p_parent)
-  : wxFrame(p_parent, -1, "", wxDefaultPosition, wxSize(500, 500)),
+  : wxFrame(p_parent, -1, _T(""), wxDefaultPosition, wxSize(500, 500)),
     m_nfg(p_nfg),
     m_table(0), m_profileTable(0),
     m_solutionWindow(0), m_infoWindow(0),
@@ -131,7 +133,7 @@ NfgShow::NfgShow(Nfg &p_nfg, wxWindow *p_parent)
   SetIcon(wxIcon("nfg_icn"));
 #else
 #include "bitmaps/nfg.xbm"
-  SetIcon(wxIcon(nfg_bits, nfg_width, nfg_height));
+  SetIcon(wxIcon(wxString::Format(_T("%s"), nfg_bits), nfg_width, nfg_height));
 #endif  // __WXMSW__
 
   m_currentProfile = 0;
@@ -153,7 +155,7 @@ NfgShow::NfgShow(Nfg &p_nfg, wxWindow *p_parent)
   CreateStatusBar();
   MakeToolbar();
 
-  m_solutionWindow = new gbtCloseFrame(this, idSOLUTIONWINDOW, "");
+  m_solutionWindow = new gbtCloseFrame(this, idSOLUTIONWINDOW, _T(""));
   m_profileTable = new NfgProfileList(this, m_solutionWindow);
   m_solutionWindow->Show(false);
 
@@ -163,7 +165,7 @@ NfgShow::NfgShow(Nfg &p_nfg, wxWindow *p_parent)
   profileSizer->Fit(m_solutionWindow);
   profileSizer->SetSizeHints(m_solutionWindow);
   
-  m_infoWindow = new gbtCloseFrame(this, idINFOWINDOW, "");
+  m_infoWindow = new gbtCloseFrame(this, idINFOWINDOW, _T(""));
   m_infoWindow->Show(true);
 
   m_infoNotebook = new wxNotebook(m_infoWindow, idINFONOTEBOOK);
@@ -174,14 +176,14 @@ NfgShow::NfgShow(Nfg &p_nfg, wxWindow *p_parent)
   infoWindowSizer->Add(notebookSizer, 1, wxEXPAND, 0);
 
   m_navigateWindow = new NfgNavigateWindow(this, m_infoNotebook);
-  m_infoNotebook->AddPage(m_navigateWindow, "Navigation");
+  m_infoNotebook->AddPage(m_navigateWindow, _T("Navigation"));
 
   m_outcomeWindow = new NfgOutcomeWindow(this, m_infoNotebook);
   m_outcomeWindow->UpdateValues();
-  m_infoNotebook->AddPage(m_outcomeWindow, "Outcomes");
+  m_infoNotebook->AddPage(m_outcomeWindow, _T("Outcomes"));
 
   m_supportWindow = new NfgSupportWindow(this, m_infoNotebook);
-  m_infoNotebook->AddPage(m_supportWindow, "Supports");
+  m_infoNotebook->AddPage(m_supportWindow, _T("Supports"));
   m_infoNotebook->SetSelection(0);
 
   m_infoWindow->SetSizer(infoWindowSizer);
@@ -381,91 +383,102 @@ gText NfgShow::UniqueOutcomeName(void) const
 void NfgShow::MakeMenus(void)
 {
   wxMenu *fileMenu = new wxMenu;
-  fileMenu->Append(wxID_NEW, "&New\tCtrl-N", "Create a new game");
-  fileMenu->Append(wxID_OPEN, "&Open\tCtrl-O", "Open a saved game");
-  fileMenu->Append(wxID_CLOSE, "&Close", "Close this window");
+  fileMenu->Append(wxID_NEW, _("&New\tCtrl-N"), _("Create a new game"));
+  fileMenu->Append(wxID_OPEN, _("&Open\tCtrl-O"), _("Open a saved game"));
+  fileMenu->Append(wxID_CLOSE, _("&Close"), _("Close this window"));
   fileMenu->AppendSeparator();
-  fileMenu->Append(wxID_SAVE, "&Save\tCtrl-S", "Save this game");
-  fileMenu->Append(wxID_SAVEAS, "Save &as", "Save game to a different file");
+  fileMenu->Append(wxID_SAVE, _("&Save\tCtrl-S"), _("Save this game"));
+  fileMenu->Append(wxID_SAVEAS, _("Save &as"), 
+		   _("Save game to a different file"));
   fileMenu->AppendSeparator();
-  fileMenu->Append(wxID_PRINT_SETUP, "Page Se&tup",
-		   "Set up preferences for printing");
-  fileMenu->Append(wxID_PREVIEW, "Print Pre&view",
-		   "View a preview of the game printout");
-  fileMenu->Append(wxID_PRINT, "&Print\tCtrl-P", "Print this game");
+  wxMenu *fileExportMenu = new wxMenu;
+  fileExportMenu->Append(NFG_FILE_EXPORT_HTML, _("&HTML"),
+			 _("Export the game to a HTML table"));
+  fileExportMenu->Append(NFG_FILE_EXPORT_OSBORNE, _("&Osborne"),
+			 _("Export the game to Osborne's LaTeX style"));
+  fileMenu->Append(NFG_FILE_EXPORT, _("&Export"), fileExportMenu, 
+		   _("Export the game to graphical formats"));
   fileMenu->AppendSeparator();
-  fileMenu->Append(wxID_EXIT, "E&xit\tCtrl-X", "Exit Gambit");
+  fileMenu->Append(wxID_PRINT_SETUP, _("Page Se&tup"),
+		   _("Set up preferences for printing"));
+  fileMenu->Append(wxID_PREVIEW, _("Print Pre&view"),
+		   _("View a preview of the game printout"));
+  fileMenu->Append(wxID_PRINT, _("&Print\tCtrl-P"), _("Print this game"));
+  fileMenu->AppendSeparator();
+  fileMenu->Append(wxID_EXIT, _("E&xit\tCtrl-X"), _("Exit Gambit"));
   
   wxMenu *editMenu = new wxMenu;
-  editMenu->Append(wxID_CUT, "Cu&t", "Cut the current selection");
-  editMenu->Append(wxID_COPY, "&Copy", "Copy the current selection");
-  editMenu->Append(wxID_PASTE, "&Paste", "Paste from clipboard");
+  editMenu->Append(wxID_CUT, _("Cu&t"), _("Cut the current selection"));
+  editMenu->Append(wxID_COPY, _("&Copy"), _("Copy the current selection"));
+  editMenu->Append(wxID_PASTE, _("&Paste"), _("Paste from clipboard"));
   // For the moment, these are not implemented -- leave disabled
   editMenu->Enable(wxID_CUT, false);
   editMenu->Enable(wxID_COPY, false);
   editMenu->Enable(wxID_PASTE, false);
   editMenu->AppendSeparator();
-  editMenu->Append(NFG_EDIT_STRATS, "&Strategies", "Edit strategy names");
-  editMenu->Append(NFG_EDIT_CONTINGENCY, "&Contingency",
-		   "Edit the selected contingency");
-  editMenu->Append(NFG_EDIT_GAME, "&Game", "Edit game properties");
+  editMenu->Append(NFG_EDIT_STRATS, _("&Strategies"), _("Edit strategy names"));
+  editMenu->Append(NFG_EDIT_CONTINGENCY, _("&Contingency"),
+		   _("Edit the selected contingency"));
+  editMenu->Append(NFG_EDIT_GAME, _("&Game"), _("Edit game properties"));
 
   wxMenu *viewMenu = new wxMenu;
-  viewMenu->Append(NFG_VIEW_PROFILES, "&Profiles",
-		   "Display/hide profiles window", true);
+  viewMenu->Append(NFG_VIEW_PROFILES, _("&Profiles"),
+		   _("Display/hide profiles window"), true);
   viewMenu->Check(NFG_VIEW_PROFILES, false);
   viewMenu->AppendSeparator();
-  viewMenu->Append(NFG_VIEW_NAVIGATION, "&Navigation",
-		   "Display navigation window", true);
+  viewMenu->Append(NFG_VIEW_NAVIGATION, _("&Navigation"),
+		   _("Display navigation window"), true);
   viewMenu->Check(NFG_VIEW_NAVIGATION, true);
-  viewMenu->Append(NFG_VIEW_OUTCOMES, "&Outcomes", 
-		   "Display and edit outcomes", true);
+  viewMenu->Append(NFG_VIEW_OUTCOMES, _("&Outcomes"), 
+		   _("Display and edit outcomes"), true);
   viewMenu->Check(NFG_VIEW_OUTCOMES, false);
-  viewMenu->Append(NFG_VIEW_SUPPORTS, "&Supports",
-		   "Display and edit supports", true);
+  viewMenu->Append(NFG_VIEW_SUPPORTS, _("&Supports"),
+		   _("Display and edit supports"), true);
   viewMenu->Check(NFG_VIEW_SUPPORTS, false);
   viewMenu->AppendSeparator();
-  viewMenu->Append(NFG_VIEW_DOMINANCE, "&Dominance",
-		   "Display dominance information", TRUE);
-  viewMenu->Append(NFG_VIEW_PROBABILITIES, "&Probabilities",
-		   "Display solution probabilities", TRUE);
-  viewMenu->Append(NFG_VIEW_VALUES, "&Values",
-		   "Display strategy values", TRUE);
+  viewMenu->Append(NFG_VIEW_DOMINANCE, _("&Dominance"),
+		   _("Display dominance information"), TRUE);
+  viewMenu->Append(NFG_VIEW_PROBABILITIES, _("&Probabilities"),
+		   _("Display solution probabilities"), TRUE);
+  viewMenu->Append(NFG_VIEW_VALUES, _("&Values"),
+		   _("Display strategy values"), TRUE);
   viewMenu->AppendSeparator();
   // This probably belongs in formatting instead
-  viewMenu->Append(NFG_VIEW_OUTCOME_LABELS, "Outcome &Labels",
-		   "Display outcome labels", TRUE);
+  viewMenu->Append(NFG_VIEW_OUTCOME_LABELS, _("Outcome &Labels"),
+		   _("Display outcome labels"), TRUE);
   
   wxMenu *formatMenu = new wxMenu;
   wxMenu *formatDisplayMenu = new wxMenu;
-  formatDisplayMenu->Append(NFG_FORMAT_DISPLAY_DECIMALS, "&Decimal Places",
-			   "Set number of decimal places to display");
+  formatDisplayMenu->Append(NFG_FORMAT_DISPLAY_DECIMALS, _("&Decimal Places"),
+			    _("Set number of decimal places to display"));
 
-  formatMenu->Append(NFG_FORMAT_DISPLAY, "&Display", formatDisplayMenu,
-		    "Configure display options");
+  formatMenu->Append(NFG_FORMAT_DISPLAY, _("&Display"), formatDisplayMenu,
+		     _("Configure display options"));
   wxMenu *formatFontMenu = new wxMenu;
-  formatFontMenu->Append(NFG_FORMAT_FONT_DATA, "&Data", "Set data font");
-  formatFontMenu->Append(NFG_FORMAT_FONT_LABELS, "&Labels", "Set label font");
-  formatMenu->Append(NFG_FORMAT_FONT, "&Font", formatFontMenu, "Set fonts");
+  formatFontMenu->Append(NFG_FORMAT_FONT_DATA, _("&Data"), _("Set data font"));
+  formatFontMenu->Append(NFG_FORMAT_FONT_LABELS, _("&Labels"), 
+			 _("Set label font"));
+  formatMenu->Append(NFG_FORMAT_FONT, _("&Font"), formatFontMenu,
+		     _("Set fonts"));
 
   wxMenu *toolsMenu = new wxMenu;
-  toolsMenu->Append(NFG_TOOLS_DOMINANCE, "&Dominance",
-		       "Find undominated strategies");
-  toolsMenu->Append(NFG_TOOLS_EQUILIBRIUM, "&Equilibrium",
-		    "Compute Nash equilibria (and refinements)");
-  toolsMenu->Append(NFG_TOOLS_QRE, "&Qre",
-		    "Compute quantal response equilibria");
+  toolsMenu->Append(NFG_TOOLS_DOMINANCE, _("&Dominance"),
+		    _("Find undominated strategies"));
+  toolsMenu->Append(NFG_TOOLS_EQUILIBRIUM, _("&Equilibrium"),
+		    _("Compute Nash equilibria (and refinements)"));
+  toolsMenu->Append(NFG_TOOLS_QRE, _("&Qre"),
+		    _("Compute quantal response equilibria"));
   
   wxMenu *helpMenu = new wxMenu;
-  helpMenu->Append(wxID_ABOUT, "&About", "About Gambit");
+  helpMenu->Append(wxID_ABOUT, _("&About"), _("About Gambit"));
 
   wxMenuBar *menuBar = new wxMenuBar(wxMB_DOCKABLE);
-  menuBar->Append(fileMenu, "&File");
-  menuBar->Append(editMenu, "&Edit");
-  menuBar->Append(viewMenu, "&View");
-  menuBar->Append(formatMenu, "&Format");
-  menuBar->Append(toolsMenu, "&Tools");
-  menuBar->Append(helpMenu, "&Help");
+  menuBar->Append(fileMenu, _("&File"));
+  menuBar->Append(editMenu, _("&Edit"));
+  menuBar->Append(viewMenu, _("&View"));
+  menuBar->Append(formatMenu, _("&Format"));
+  menuBar->Append(toolsMenu, _("&Tools"));
+  menuBar->Append(helpMenu, _("&Help"));
 
   SetMenuBar(menuBar);
 }
@@ -484,22 +497,22 @@ void NfgShow::MakeToolbar(void)
   toolBar->SetMargins(4, 4);
 
   toolBar->AddTool(wxID_NEW, wxBITMAP(new), wxNullBitmap, false,
-		   -1, -1, 0, "New game", "Create a new game");
+		   -1, -1, 0, _("New game"), _("Create a new game"));
   toolBar->AddTool(wxID_OPEN, wxBITMAP(open), wxNullBitmap, false,
-		   -1, -1, 0, "Open file", "Open a saved game");
+		   -1, -1, 0, _("Open file"), _("Open a saved game"));
   toolBar->AddTool(wxID_SAVE, wxBITMAP(save), wxNullBitmap, false,
-		   -1, -1, 0, "Save game", "Save this game");
+		   -1, -1, 0, _("Save game"), _("Save this game"));
   toolBar->AddSeparator();
 
   toolBar->AddTool(wxID_PREVIEW, wxBITMAP(preview), wxNullBitmap,
-		   false, -1, -1, 0, "Print Preview",
-		   "View a preview of the game printout");
+		   false, -1, -1, 0, _("Print Preview"),
+		   _("View a preview of the game printout"));
   toolBar->AddTool(wxID_PRINT, wxBITMAP(print), wxNullBitmap, false,
-		   -1, -1, 0, "Print", "Print this game");
+		   -1, -1, 0, _("Print"), _("Print this game"));
   toolBar->AddSeparator();
 
   toolBar->AddTool(wxID_ABOUT, wxBITMAP(help), wxNullBitmap, false,
-		   -1, -1, 0, "Help", "Table of contents");
+		   -1, -1, 0, _("Help"), _("Table of contents"));
 
   toolBar->Realize();
   toolBar->SetRows(1);
@@ -529,11 +542,16 @@ void NfgShow::OnFileOpen(wxCommandEvent &)
   wxGetApp().OnFileOpen(this);
 }
 
+void NfgShow::OnFileClose(wxCommandEvent &)
+{
+  Close();
+}
+
 void NfgShow::OnFileSave(wxCommandEvent &p_event)
 {
-  if (p_event.GetId() == wxID_SAVEAS || m_filename == "") {
-    wxFileDialog dialog(this, "Choose file", wxPathOnly(m_filename),
-			wxFileNameFromPath(m_filename), "*.nfg",
+  if (p_event.GetId() == wxID_SAVEAS || m_filename == _T("")) {
+    wxFileDialog dialog(this, _("Choose file"), wxPathOnly(m_filename),
+			wxFileNameFromPath(m_filename), _T("*.nfg"),
 			wxSAVE | wxOVERWRITE_PROMPT);
 
     switch (dialog.ShowModal()) {
@@ -548,30 +566,93 @@ void NfgShow::OnFileSave(wxCommandEvent &p_event)
 
   Nfg *nfg = 0;
   try {
-    gFileOutput file(m_filename.c_str());
+    gFileOutput file((const char *) m_filename.mb_str());
     nfg = CompressNfg(m_nfg, *m_currentSupport);
     nfg->WriteNfgFile(file, 6);
     m_nfg.SetIsDirty(false);
     delete nfg;
   }
   catch (gFileOutput::OpenFailed &) {
-    wxMessageBox(wxString::Format("Could not open %s for writing.",
-				  m_filename.c_str()),
-		 "Error", wxOK, this);
+    wxMessageBox(wxString::Format(_("Could not open %s for writing."),
+				  (const char *) m_filename.mb_str()),
+		 _("Error"), wxOK, this);
     if (nfg)  delete nfg;
   }
   catch (gFileOutput::WriteFailed &) {
-    wxMessageBox(wxString::Format("Write error occurred in saving %s.\n",
-				  m_filename.c_str()),
-		 "Error", wxOK, this);
+    wxMessageBox(wxString::Format(_("Write error occurred in saving %s."),
+				    (const char *) m_filename.mb_str()),
+		 _("Error"), wxOK, this);
     if (nfg)  delete nfg;
   }
   catch (gException &) {
-    wxMessageBox("Internal exception in Gambit", "Error", wxOK, this);
+    wxMessageBox(_("Internal exception in Gambit"), _("Error"), wxOK, this);
     if (nfg)  delete nfg;
   }
 }
 
+void NfgShow::OnFileExportHTML(wxCommandEvent &)
+{
+  wxFileDialog dialog(this, _("Choose output file"),
+		      wxGetApp().CurrentDir(), wxT(""),
+		      _("HTML files (*.html)|*.html|"
+			"HTML files (*.htm)|*.htm"), wxSAVE);
+
+  if (dialog.ShowModal() != wxID_OK) {
+    return;
+  }
+  
+  try {
+    gFileOutput file(dialog.GetPath().mb_str());
+    m_nfg.WriteHtmlFile(file, 
+			m_table->GetRowPlayer(), m_table->GetColPlayer());
+  }
+  catch (gFileOutput::OpenFailed &) { 
+    wxMessageBox(wxString::Format(_("Could not open %s for writing."),
+				  (const char *) dialog.GetPath().mb_str()),
+		 _("Error"), wxOK, this);
+  }
+  catch (gFileOutput::WriteFailed &) {
+    wxMessageBox(wxString::Format(_("Write error occurred in saving %s."),
+				  (const char *) dialog.GetPath().mb_str()),
+		 _("Error"), wxOK, this);
+  }
+  catch (...) {
+    wxMessageBox(_("An internal exeception occurred in Gambit"), _("Error"),
+		 wxOK, this);
+  }
+}
+
+void NfgShow::OnFileExportOsborne(wxCommandEvent &)
+{
+  wxFileDialog dialog(this, _("Choose output file"),
+		      wxGetApp().CurrentDir(), wxT(""),
+		      _("LaTeX files (*.tex)|*.tex"), wxSAVE);
+
+  if (dialog.ShowModal() != wxID_OK) {
+    return;
+  }
+  
+  try {
+    gFileOutput file(dialog.GetPath().mb_str());
+    m_nfg.WriteOsborneFile(file, 
+			   m_table->GetRowPlayer(), m_table->GetColPlayer());
+  }
+  catch (gFileOutput::OpenFailed &) { 
+    wxMessageBox(wxString::Format(_("Could not open %s for writing."),
+				  (const char *) dialog.GetPath().mb_str()),
+		 _("Error"), wxOK, this);
+  }
+  catch (gFileOutput::WriteFailed &) {
+    wxMessageBox(wxString::Format(_("Write error occurred in saving %s."),
+				  (const char *) dialog.GetPath().mb_str()),
+		 _("Error"), wxOK, this);
+  }
+  catch (...) {
+    wxMessageBox(_("An internal exeception occurred in Gambit"), _("Error"),
+		 wxOK, this);
+  }
+}
+
 void NfgShow::OnFilePageSetup(wxCommandEvent &)
 {
   wxPageSetupDialog dialog(this, &m_pageSetupData);
@@ -588,11 +669,11 @@ void NfgShow::OnFilePrintPreview(wxCommandEvent &)
     new wxPrintPreview(new NfgPrintout(m_nfg, 
 				       m_table->GetRowPlayer(), 
 				       m_table->GetColPlayer(),
-				       (char *) m_nfg.GetTitle()),
+				       wxString::Format(_T("%s"), (char *) m_nfg.GetTitle())),
 		       new NfgPrintout(m_nfg,
 				       m_table->GetRowPlayer(),
 				       m_table->GetColPlayer(),
-				       (char *) m_nfg.GetTitle()),
+				       wxString::Format(_T("%s"), (char *) m_nfg.GetTitle())),
 		       &data);
 
   if (!preview->Ok()) {
@@ -601,7 +682,7 @@ void NfgShow::OnFilePrintPreview(wxCommandEvent &)
   }
 
   wxPreviewFrame *frame = new wxPreviewFrame(preview, this,
-					     "Print Preview",
+					     _("Print Preview"),
 					     wxPoint(100, 100),
 					     wxSize(600, 650));
   frame->Initialize();
@@ -613,11 +694,11 @@ void NfgShow::OnFilePrint(wxCommandEvent &)
   wxPrintDialogData data(m_printData);
   wxPrinter printer(&data);
   NfgPrintout printout(m_nfg, m_table->GetRowPlayer(), m_table->GetColPlayer(),
-		       (char *) m_nfg.GetTitle());
+		       wxString::Format(_T("%s"), (char *) m_nfg.GetTitle()));
 
   if (!printer.Print(this, &printout, true)) {
     if (wxPrinter::GetLastError() == wxPRINTER_ERROR) {
-      wxMessageBox("There was an error in printing", "Error", wxOK);
+      wxMessageBox(_("There was an error in printing"), _("Error"), wxOK);
     }
     // Otherwise, user hit "cancel"; just be quiet and return.
     return;
@@ -678,11 +759,11 @@ void NfgShow::OnEditGame(wxCommandEvent &)
 {
   dialogNfgProperties dialog(this, m_nfg, m_filename);
   if (dialog.ShowModal() == wxID_OK) {
-    m_nfg.SetTitle(dialog.GetGameTitle().c_str());
+    m_nfg.SetTitle((const char *) dialog.GetGameTitle().mb_str());
     SetFilename(Filename());
-    m_nfg.SetComment(dialog.GetComment().c_str());
+    m_nfg.SetComment((const char *) dialog.GetComment().mb_str());
     for (int pl = 1; pl <= dialog.NumPlayers(); pl++) {
-      m_nfg.Players()[pl]->SetName(dialog.GetPlayerName(pl).c_str());
+      m_nfg.Players()[pl]->SetName((const char *) dialog.GetPlayerName(pl).mb_str());
     }
     m_navigateWindow->UpdateLabels();
     m_outcomeWindow->UpdateValues();
@@ -795,7 +876,7 @@ void NfgShow::OnViewOutcomeLabels(wxCommandEvent &)
 
 void NfgShow::OnFormatDisplayDecimals(wxCommandEvent &)
 {
-  dialogSpinCtrl dialog(this, "Decimal places", 0, 25,
+  dialogSpinCtrl dialog(this, _("Decimal places"), 0, 25,
 			m_table->GetSettings().GetDecimals());
 
   if (dialog.ShowModal() == wxID_OK) {
@@ -964,8 +1045,8 @@ void NfgShow::OnToolsQre(wxCommandEvent &)
     catch (gSignalBreak &) { }
     catch (...) {
       wxMessageDialog message(this,
-			      "An exception occurred in computing equilibria",
-			      "Error", wxID_OK);
+			      _("An exception occurred in computing equilibria"),
+			      _("Error"), wxID_OK);
       message.ShowModal();
     }
 
@@ -1060,7 +1141,19 @@ void NfgShow::OnProfilesDeleteAll(wxCommandEvent &)
   UpdateMenus();
 }
 
-void NfgShow::OnProfilesProperties(wxCommandEvent &)
+void NfgShow::OnProfilesPropertiesCmd(wxCommandEvent &)
+{
+  if (m_currentProfile > 0) {
+    dialogEditMixed dialog(this, m_profiles[m_currentProfile]);
+
+    if (dialog.ShowModal() == wxID_OK) {
+      m_profiles[m_currentProfile] = dialog.GetProfile();
+      ChangeProfile(m_currentProfile);
+    }
+  }
+}
+
+void NfgShow::OnProfilesPropertiesClick(wxListEvent &)
 {
   if (m_currentProfile > 0) {
     dialogEditMixed dialog(this, m_profiles[m_currentProfile]);
@@ -1085,7 +1178,7 @@ void NfgShow::OnProfilesReport(wxCommandEvent &)
 void NfgShow::OnCloseWindow(wxCloseEvent &p_event)
 {
   if (p_event.CanVeto() && GameIsDirty()) {
-    if (wxMessageBox("Game has been modified.  Close anyway?", "Warning",
+    if (wxMessageBox(_("Game has been modified.  Close anyway?"), _("Warning"),
 		     wxOK | wxCANCEL) == wxCANCEL) {
       p_event.Veto();
       return;
@@ -1133,16 +1226,17 @@ gText NfgShow::UniqueSupportName(void) const
 void NfgShow::SetFilename(const wxString &p_name)
 {
   m_filename = p_name;
-  if (m_filename != "") {
-    SetTitle(wxString::Format("Gambit - [%s] %s", m_filename.c_str(), 
+  if (m_filename != _T("")) {
+    SetTitle(wxString::Format(_T("Gambit - [%s] %s"), 
+			      (const char *) m_filename.mb_str(), 
 			      (char *) m_nfg.GetTitle()));
   }
   else {
-    SetTitle(wxString::Format("Gambit - %s", (char *) m_nfg.GetTitle()));
+    SetTitle(wxString::Format(_T("Gambit - %s"), (char *) m_nfg.GetTitle()));
   }
-  m_infoWindow->SetTitle(wxString::Format("Gambit - Info: %s",
+  m_infoWindow->SetTitle(wxString::Format(_T("Gambit - Info: %s"),
 					  (char *) m_nfg.GetTitle()));
-  m_solutionWindow->SetTitle(wxString::Format("Gambit - Profiles: %s",
+  m_solutionWindow->SetTitle(wxString::Format(_T("Gambit - Profiles: %s"),
 					      (char *) m_nfg.GetTitle()));
 
   wxGetApp().SetFilename(this, p_name.c_str());
