@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/gui/nfgtable.cc,v $
-// $Date: 2002/09/12 18:52:41 $
-// $Revision: 1.12.2.3 $
+// $Date: 2004/08/17 17:53:51 $
+// $Revision: 1.12.2.14 $
 //
 // DESCRIPTION:
 // Implementation of normal form table class
@@ -45,11 +45,11 @@ NfgTableSettings::NfgTableSettings(void)
 void NfgTableSettings::SaveFont(const wxString &p_prefix, 
 				wxConfig &p_config, const wxFont &p_font)
 {
-  p_config.Write(p_prefix + "Size", (long) p_font.GetPointSize());
-  p_config.Write(p_prefix + "Family", (long) p_font.GetFamily());
-  p_config.Write(p_prefix + "Face", p_font.GetFaceName());
-  p_config.Write(p_prefix + "Style", (long) p_font.GetStyle());
-  p_config.Write(p_prefix + "Weight", (long) p_font.GetWeight());
+  p_config.Write(p_prefix + _T("Size"), (long) p_font.GetPointSize());
+  p_config.Write(p_prefix + _T("Family"), (long) p_font.GetFamily());
+  p_config.Write(p_prefix + _T("Face"), p_font.GetFaceName());
+  p_config.Write(p_prefix + _T("Style"), (long) p_font.GetStyle());
+  p_config.Write(p_prefix + _T("Weight"), (long) p_font.GetWeight());
 }
 
 void NfgTableSettings::LoadFont(const wxString &p_prefix,
@@ -57,11 +57,11 @@ void NfgTableSettings::LoadFont(const wxString &p_prefix,
 {
   long size, family, style, weight;
   wxString face;
-  p_config.Read(p_prefix + "Size", &size, 10);
-  p_config.Read(p_prefix + "Family", &family, wxMODERN);
-  p_config.Read(p_prefix + "Face", &face, "");
-  p_config.Read(p_prefix + "Style", &style, wxNORMAL);
-  p_config.Read(p_prefix + "Weight", &weight, wxNORMAL);
+  p_config.Read(p_prefix + _T("Size"), &size, 10);
+  p_config.Read(p_prefix + _T("Family"), &family, wxMODERN);
+  p_config.Read(p_prefix + _T("Face"), &face, _T(""));
+  p_config.Read(p_prefix + _T("Style"), &style, wxNORMAL);
+  p_config.Read(p_prefix + _T("Weight"), &weight, wxNORMAL);
 
   p_font = *wxTheFontList->FindOrCreateFont(size, family, style, weight,
 					    false, face);
@@ -69,22 +69,22 @@ void NfgTableSettings::LoadFont(const wxString &p_prefix,
 
 void NfgTableSettings::LoadSettings(void)
 {
-  wxConfig config("Gambit");
-  config.Read("/NfgDisplay/DisplayPrecision", &m_decimals, 2);
-  config.Read("/NfgDisplay/OutcomeValues", &m_outcomeValues, true);
+  wxConfig config(_T("Gambit"));
+  config.Read(_T("/NfgDisplay/DisplayPrecision"), &m_decimals, 2);
+  config.Read(_T("/NfgDisplay/OutcomeValues"), &m_outcomeValues, true);
 
-  LoadFont("/NfgDisplay/DataFont", config, m_dataFont);
-  LoadFont("/NfgDisplay/LabelFont", config, m_labelFont);
+  LoadFont(_T("/NfgDisplay/DataFont"), config, m_dataFont);
+  LoadFont(_T("/NfgDisplay/LabelFont"), config, m_labelFont);
 }
 
 void NfgTableSettings::SaveSettings(void) const
 {
-  wxConfig config("Gambit");
-  config.Write("/NfgDisplay/DisplayPrecision", (long) m_decimals);
-  config.Write("/NfgDisplay/OutcomeValues", (long) m_outcomeValues);
+  wxConfig config(_T("Gambit"));
+  config.Write(_T("/NfgDisplay/DisplayPrecision"), (long) m_decimals);
+  config.Write(_T("/NfgDisplay/OutcomeValues"), (long) m_outcomeValues);
 
-  SaveFont("/NfgDisplay/DataFont", config, m_dataFont);
-  SaveFont("/NfgDisplay/LabelFont", config, m_labelFont);
+  SaveFont(_T("/NfgDisplay/DataFont"), config, m_dataFont);
+  SaveFont(_T("/NfgDisplay/LabelFont"), config, m_labelFont);
 }
 
 //---------------------------------------------------------------------
@@ -140,17 +140,17 @@ wxString NfgGridTable::GetRowLabelValue(int p_row)
 {
   int numStrats = m_table->GetSupport().NumStrats(m_table->GetRowPlayer());
   if (p_row + 1 <= numStrats) {
-    return (char *) m_table->GetSupport().Strategies(m_table->GetRowPlayer())[p_row+1]->Name();
+    return wxString::Format(_T("%s"), (char *) m_table->GetSupport().Strategies(m_table->GetRowPlayer())[p_row+1]->Name());
   }
   else if (p_row + 1 == numStrats + m_table->ShowDominance()) {
-    return "Dom";
+    return _T("Dom");
   }
   else if (p_row + 1 == 
 	   numStrats + m_table->ShowDominance() + m_table->ShowProbs()) {
-    return "Prob";
+    return _T("Prob");
   }
   else {
-    return "Val";
+    return _T("Val");
   }
 }
 
@@ -158,17 +158,17 @@ wxString NfgGridTable::GetColLabelValue(int p_col)
 {
   int numStrats = m_table->GetSupport().NumStrats(m_table->GetColPlayer());
   if (p_col + 1 <= numStrats) {
-    return (char *) m_table->GetSupport().Strategies(m_table->GetColPlayer())[p_col+1]->Name();
+    return wxString::Format(_T("%s"), (char *) m_table->GetSupport().Strategies(m_table->GetColPlayer())[p_col+1]->Name());
   }
   else if (p_col + 1 == numStrats + m_table->ShowDominance()) {
-    return "Dom";
+    return _T("Dom");
   }
   else if (p_col + 1 == 
 	   numStrats + m_table->ShowDominance() + m_table->ShowProbs()) {
-    return "Prob";
+    return _T("Prob");
   }
   else {
-    return "Val";
+    return _T("Val");
   }
 }
 
@@ -192,28 +192,29 @@ wxString NfgGridTable::GetValue(int row, int col)
 
     NFOutcome *outcome = m_nfg->GetOutcome(profile);
     if (m_table->GetSettings().OutcomeValues()) {
-      wxString ret = "(";
+      wxString ret = _T("(");
       for (int pl = 1; pl <= strategy.Length(); pl++) {
-	ret += wxString::Format("%s",
+	ret += wxString::Format(_T("%s"),
 				(char *) ToText(m_nfg->Payoff(outcome, pl),
 						m_table->GetSettings().GetDecimals()));
 	if (pl < strategy.Length()) {
-	  ret += wxString(",");
+	  ret += _T(",");
 	}
       }
-      ret += ")";
+      ret += _T(")");
       return ret;
     }
     else {
       if (outcome) {
-	wxString ret = (char *) outcome->GetName();
-	if (ret == "") {
-	  ret = (char *) (gText("Outcome") + ToText(outcome->GetNumber()));
+	wxString ret = wxString::Format(_T("%s"), (char *) outcome->GetName());
+	if (ret == _T("")) {
+	  ret = wxString::Format(_T("%s"), 
+				 (char *) (gText("Outcome") + ToText(outcome->GetNumber())));
 	}
 	return ret;
       }
       else {
-	return "Null";
+	return _T("Null");
       }
     }
   }
@@ -221,50 +222,50 @@ wxString NfgGridTable::GetValue(int row, int col)
 	   col == numColStrats + m_table->ShowDominance() - 1) {
     Strategy *strategy = support.GetStrategy(rowPlayer, row + 1);
     if (support.IsDominated(strategy, true)) {
-      return "S";
+      return _T("S");
     }
     else if (support.IsDominated(strategy, false)) {
-      return "W";
+      return _T("W");
     }
     else {
-      return "N";
+      return _T("N");
     }
   }
   else if (row == numRowStrats + m_table->ShowDominance() - 1 &&
 	   col < numColStrats) {
     Strategy *strategy = support.GetStrategy(colPlayer, col + 1);
     if (support.IsDominated(strategy, true)) {
-      return "S";
+      return _T("S");
     }
     else if (support.IsDominated(strategy, false)) {
-      return "W";
+      return _T("W");
     }
     else {
-      return "N";
+      return _T("N");
     }
   }
   else if (row < numRowStrats && 
 	   col == numColStrats + m_table->ShowDominance() + m_table->ShowProbs() - 1) {
     Strategy *strategy = support.GetStrategy(rowPlayer, row + 1);
-    return ((char *) ToText(m_table->GetProfile()(strategy)));
+    return wxString::Format(_T("%s"), (char *) ToText(m_table->GetProfile()(strategy)));
   }
   else if (row == numRowStrats + m_table->ShowDominance() + m_table->ShowProbs() - 1 && 
 	   col < numColStrats) {
     Strategy *strategy = support.GetStrategy(colPlayer, col + 1);
-    return ((char *) ToText(m_table->GetProfile()(strategy)));
+    return wxString::Format(_T("%s"), (char *) ToText(m_table->GetProfile()(strategy)));
   }
   else if (row < numRowStrats && 
 	   col == numColStrats + m_table->ShowDominance() + m_table->ShowProbs() + m_table->ShowValues() - 1) {
     Strategy *strategy = support.GetStrategy(rowPlayer, row + 1);
-    return ((char *) ToText(m_table->GetProfile().Payoff(strategy->Player(), strategy)));
+    return wxString::Format(_T("%s"), (char *) ToText(m_table->GetProfile().Payoff(strategy->Player(), strategy)));
   }
   else if (row == numRowStrats + m_table->ShowDominance() + m_table->ShowProbs() + m_table->ShowValues() - 1 && 
 	   col < numColStrats) {
     Strategy *strategy = support.GetStrategy(colPlayer, col + 1);
-    return ((char *) ToText(m_table->GetProfile().Payoff(strategy->Player(), strategy)));
+    return wxString::Format(_T("%s"), (char *) ToText(m_table->GetProfile().Payoff(strategy->Player(), strategy)));
   }
 
-  return "";
+  return _T("");
 }
 
 void NfgGridTable::SetValue(int row, int col, const wxString &)
@@ -429,8 +430,8 @@ void ColoredStringRenderer::Draw(wxGrid& grid,
   rect.Inflate(-1);
 
   wxCoord x, y;
-  grid.DrawTextRectangle(dc, wxString("("), rect);
-  dc.GetTextExtent("(", &x, &y);
+  grid.DrawTextRectangle(dc, _T("("), rect);
+  dc.GetTextExtent(_T("("), &x, &y);
   rect.x += x;
 
   wxString text = grid.GetCellValue(row, col);
@@ -439,8 +440,8 @@ void ColoredStringRenderer::Draw(wxGrid& grid,
     if (text[i] == ',') {
       wxColour color = dc.GetTextForeground();
       dc.SetTextForeground(*wxBLACK);
-      grid.DrawTextRectangle(dc, wxString(","), rect);
-      dc.GetTextExtent(",", &x, &y);
+      grid.DrawTextRectangle(dc, _T(","), rect);
+      dc.GetTextExtent(_T(","), &x, &y);
       rect.x += x;
 
       if (color == *wxRED) {
@@ -451,14 +452,14 @@ void ColoredStringRenderer::Draw(wxGrid& grid,
       }
     }
     else {
-      grid.DrawTextRectangle(dc, wxString(text[i]), rect);
+      grid.DrawTextRectangle(dc, wxString::Format(_T("%c"), (text[i])), rect);
       dc.GetTextExtent(text[i], &x, &y);
       rect.x += x;
     }
   }
   
   dc.SetTextForeground(*wxBLACK);
-  grid.DrawTextRectangle(dc, wxString(")"), rect); 
+  grid.DrawTextRectangle(dc, _T(")"), rect); 
 }
 
 //======================================================================
