@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/math/gsmatrix.cc,v $
-// $Date: 2002/08/26 05:50:03 $
-// $Revision: 1.5 $
+// $Date: 2003/12/12 20:17:31 $
+// $Revision: 1.5.2.1 $
 //
 // DESCRIPTION:
 // Instantiation of common square matrix types
@@ -28,6 +28,13 @@
 #include "rational.h"
 #include "double.h"
 
+gMatrixSingular::~gMatrixSingular() { }
+
+gText gMatrixSingular::Description(void) const
+{
+  return "Attempted to invert a singular matrix";
+}
+
 template class gSquareMatrix<double>;
 template class gSquareMatrix<gDouble>;
 template class gSquareMatrix<gRational>;
