@@ -1,7 +1,7 @@
 //
 // $Source: /cvsroot/gambit/gambit/sources/wxgcl/Attic/wxgcl.cc,v $
-// $Date: 2003/09/01 00:28:28 $
-// $Revision: 1.5.2.1 $
+// $Date: 2004/04/10 17:50:23 $
+// $Revision: 1.5.2.3 $
 //
 // DESCRIPTION:
 // wxWindows-based interface to GCL
@@ -303,6 +303,12 @@ public:
 
 bool GclApp::OnInit(void)
 {
+  // wxWidgets internals sometimes issue warnings for things
+  // that aren't a big deal (such as unknown entries in .mime.types
+  // under GTK).  Since we don't actually use the wxWidgets
+  // logging facilities ourselves, we'll just silence these.
+  wxLog::SetLogLevel(0);
+
   // Long run feature: remember frame size from previous invocations
   GclFrame *frame = new GclFrame(0, "Gambit Command Language",
 				 wxPoint(0, 0), wxSize(640, 480));
@@ -595,7 +601,8 @@ void GclFrame::OnSashDrag(wxSashEvent &p_event)
 void GclFrame::OnTextEnter(wxCommandEvent &)
 {
   gText input(m_inputWindow->GetValue().c_str());
-  if (input.Right(2)[1u] == '\\') {
+
+  if (input.Length() > 1 && input.Right(2)[1u] == '\\') {
     // continuation character
     m_inputWindow->AppendText("\n");
     return;
